<?php


namespace Drupal\custom_elements_thunder\Processor;

use Drupal\custom_elements\CustomElement;
use Drupal\custom_elements\Processor\CustomElementProcessorInterface;
use Drupal\paragraphs\ParagraphInterface;

/**
 * Default processor for thunder image paragraph.
 */
class ParagraphImageProcessor implements CustomElementProcessorInterface {

  /**
   * {@inheritdoc}
   */
  public function supports($data, $viewMode) {
    if ($data instanceof ParagraphInterface) {
      return $data->getEntityTypeId() == 'paragraph' &&
        $data->bundle() == 'image';
    }
    else {
      return FALSE;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function addtoElement($paragraph, CustomElement $element, $viewMode) {
    assert($paragraph instanceof ParagraphInterface);

    // Always add a title attribute if field_title is there.
    if (isset($paragraph->field_title) && $paragraph->field_title->value) {
      $element->setAttribute('title', $paragraph->field_title->value);
    }

    /** @var \Drupal\media_entity\Entity\Media $media_entity */
    $media_entity = $paragraph->field_image->entity;
    if (!$media_entity) {
      return;
    }

    $element->setAttribute('src', $media_entity->field_image->entity->uri->url);

    if (!$media_entity->field_copyright->isEmpty()) {
      $element->setAttribute('copyright', $media_entity->field_copyright->value);
    }
    if (!$media_entity->field_source->isEmpty()) {
      $element->setAttribute('source', $media_entity->field_source->value);
    }
    if (!$media_entity->field_description->isEmpty()) {
      $element->setAttribute('caption', $media_entity->field_description->processed);
    }
  }

}
